@@ -1,4 +1,4 @@
-if [ "$LANGUAGE" = "zh_CN" ]; then
+if [ "`echo $LANGUAGE | grep zh_CN`" != "" ]; then
     export UNZIP="-O GBK"
     export ZIPINFO="-O GBK"
 fi
